import React from 'react';
import { FlatListProps, ListRenderItemInfo } from 'react-native';
declare type SwipableListProps<ItemT> = {
    /**
     * To alert the user that swiping is possible, the first row can bounce
     * on component mount.
     */
    bounceFirstRowOnMount?: boolean;
    maxSwipeDistance?: number | ((info: ListRenderItemInfo<ItemT>) => number);
    renderQuickActions?: (info: ListRenderItemInfo<ItemT>) => React.ReactNode;
};
declare type Props<ItemT> = SwipableListProps<ItemT> & FlatListProps<ItemT>;
/**
 * A container component that renders multiple SwipeableRow's in a FlatList
 * implementation. This is designed to be a drop-in replacement for the
 * standard React Native `FlatList`, so use it as if it were a FlatList, but
 * with extra props, i.e.
 *
 * <SwipeableListView renderRow={..} renderQuickActions={..} {..FlatList props} />
 *
 * SwipeableRow can be used independently of this component, but the main
 * benefit of using this component is
 *
 * - It ensures that at most 1 row is swiped open (auto closes others)
 * - It can bounce the 1st row of the list so users know it's swipeable
 * - Increase performance on iOS by locking list swiping when row swiping is occurring
 * - More to come
 */
export declare const SwipeableFlatList: <ItemT extends {}>(props: Props<ItemT>) => JSX.Element;
export {};
//# sourceMappingURL=SwipeableFlatList.d.ts.map